@@ -4,7 +4,7 @@ import threading
 from forecastio.models import Forecast
 
 
-def load_forecast(key, lat, lng, time=None, units="auto", lazy=False,
+def load_forecast(key, lat, lng, time=None, units="auto", lang="en", lazy=False,
                   callback=None):
     """
         This function builds the request url and loads some or all of the
@@ -17,6 +17,7 @@ def load_forecast(key, lat, lng, time=None, units="auto", lazy=False,
                time at the provided latitude and longitude.
         units:  A string of the preferred units of measurement, "auto" id
                 default. also us,ca,uk,si is available
+        lang:   Return summary properties in the desired language
         lazy:   Defaults to false.  The function will only request the json
                 data as it is needed. Results in more requests, but
                 probably a faster response time (I haven't checked)
@@ -24,12 +25,11 @@ def load_forecast(key, lat, lng, time=None, units="auto", lazy=False,
 
     if time is None:
         url = 'https://api.darksky.net/forecast/%s/%s,%s' \
-              '?units=%s' % (key, lat, lng, units,)
+              '?units=%s&lang=%s' % (key, lat, lng, units, lang)
     else:
         url_time = time.replace(microsecond=0).isoformat()  # API returns 400 for microseconds
         url = 'https://api.darksky.net/forecast/%s/%s,%s,%s' \
-              '?units=%s' % (key, lat, lng, url_time,
-              units,)
+              '?units=%s&lang=%s' % (key, lat, lng, url_time, units, lang)
 
     if lazy is True:
         baseURL = "%s&exclude=%s" % (url,
